#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 sourcemap
version:              0.1.7
visibility:           public
id:                   sourcemap-0.1.7-I4BGhC3lC3QB0UpPWwr6Oh
key:                  sourcemap-0.1.7-I4BGhC3lC3QB0UpPWwr6Oh
license:              BSD-3-Clause
copyright:            2012 Chris Done
maintainer:           Jens Petersen <juhpetersen@gmail.com>
author:               Chris Done
stability:            alpha
synopsis:
    Implementation of source maps as proposed by Google and Mozilla.

description:
    Implementation of source maps, revision 3, proposed by Google and Mozilla here
    <https://wiki.mozilla.org/DevTools/Features/SourceMap> and here
    <https://docs.google.com/document/d/1U1RGAehQwRypUTovF1KRlpiOFze0b-_2gc6fAH0KY0k/edit>

category:             Development
abi:                  24ef67b8b61f0a056b05a3fc0e105957
exposed:              True
exposed-modules:      SourceMap SourceMap.Types
hidden-modules:       VLQ
import-dirs:          /usr/lib/ghc-9.6.6/site-local/sourcemap-0.1.7
library-dirs:         /usr/lib/ghc-9.6.6/site-local/sourcemap-0.1.7
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/sourcemap-0.1.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-sourcemap
hs-libraries:         HSsourcemap-0.1.7-I4BGhC3lC3QB0UpPWwr6Oh
depends:
    aeson-2.2.1.0-1TOI5ELuqi01VCY8v7ADie
    attoparsec-0.14.4-8Ihrc92tki9CPtxJ7iMWhq base-4.18.2.1
    bytestring-0.11.5.3 process-1.6.19.0 text-2.0.2
    unordered-containers-0.2.20.1-HfKtyefgs0b2egKrxLGXU0
    utf8-string-1.0.2-2At7L47Qsbs4rlGLlJEQb1

haddock-interfaces:   /usr/share/doc/haskell-sourcemap/html/sourcemap.haddock
haddock-html:         /usr/share/doc/haskell-sourcemap/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

